import { Prop, Provide, Emit, Model } from 'vue-property-decorator';
import { Subject, Subscription } from 'rxjs';
import { Watch, EditFormControlBase } from '@/studio-core';
import OpportunityService from '@/service/opportunity/opportunity-service';
import MainService from './main-form-service';
import { FormButtonModel, FormPageModel, FormItemModel, FormDRUIPartModel, FormPartModel, FormGroupPanelModel, FormIFrameModel, FormRowItemModel, FormTabPageModel, FormTabPanelModel, FormUserControlModel } from '@/model/form-detail';


/**
 * form部件基类
 *
 * @export
 * @class EditFormControlBase
 * @extends {MainEditFormBase}
 */
export class MainEditFormBase extends EditFormControlBase {

    /**
     * 建构部件服务对象
     *
     * @type {MainService}
     * @memberof MainEditFormBase
     */
    public service: MainService = new MainService({ $store: this.$store });

    /**
     * 实体服务对象
     *
     * @type {OpportunityService}
     * @memberof MainEditFormBase
     */
    public appEntityService: OpportunityService = new OpportunityService({ $store: this.$store });

    /**
     * 应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof MainEditFormBase
     */
    protected appDeName: string = 'opportunity';

    /**
     * 关系界面数量
     *
     * @protected
     * @type {number}
     * @memberof MainEditFormBase
     */
    protected drCount: number = 0;

    /**
     * 表单数据对象
     *
     * @type {*}
     * @memberof MainEditFormBase
     */
    public data: any = {
        srfupdatedate: null,
        srforikey: null,
        srfkey: null,
        srfmajortext: null,
        srftempmode: null,
        srfuf: null,
        srfdeid: null,
        srfsourcekey: null,
        opportunityname: null,
        parentcontactname: null,
        parentaccountname: null,
        purchasetimeframe: null,
        transactioncurrencyname: null,
        budgetamount: null,
        purchaseprocess: null,
        description: null,
        currentsituation: null,
        customerneed: null,
        proposedsolution: null,
        pricelevelname: null,
        parentcontactid: null,
        parentaccountid: null,
        transactioncurrencyid: null,
        opportunityid: null,
        pricelevelid: null,
        opportunity:null,
    };

    /**
     * 属性值规则
     *
     * @type {*}
     * @memberof MainEditFormBase
     */
    public rules: any = {
        srfupdatedate: [
            { required: false, type: 'string', message: '更新时间 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: '更新时间 值不能为空', trigger: 'blur' },
        ],
        srforikey: [
            { required: false, type: 'string', message: ' 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: ' 值不能为空', trigger: 'blur' },
        ],
        srfkey: [
            { required: false, type: 'string', message: '商机 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: '商机 值不能为空', trigger: 'blur' },
        ],
        srfmajortext: [
            { required: false, type: 'string', message: '商机名称 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: '商机名称 值不能为空', trigger: 'blur' },
        ],
        srftempmode: [
            { required: false, type: 'string', message: ' 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: ' 值不能为空', trigger: 'blur' },
        ],
        srfuf: [
            { required: false, type: 'string', message: ' 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: ' 值不能为空', trigger: 'blur' },
        ],
        srfdeid: [
            { required: false, type: 'string', message: ' 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: ' 值不能为空', trigger: 'blur' },
        ],
        srfsourcekey: [
            { required: false, type: 'string', message: ' 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: ' 值不能为空', trigger: 'blur' },
        ],
        opportunityname: [
            { required: true, type: 'string', message: '商机名称 值不能为空', trigger: 'change' },
            { required: true, type: 'string', message: '商机名称 值不能为空', trigger: 'blur' },
        ],
        parentcontactname: [
            { required: false, type: 'string', message: '联系人 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: '联系人 值不能为空', trigger: 'blur' },
        ],
        parentaccountname: [
            { required: false, type: 'string', message: '帐户 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: '帐户 值不能为空', trigger: 'blur' },
        ],
        purchasetimeframe: [
            { required: false, type: 'string', message: '购买时间范围 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: '购买时间范围 值不能为空', trigger: 'blur' },
        ],
        transactioncurrencyname: [
            { required: false, type: 'string', message: '货币 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: '货币 值不能为空', trigger: 'blur' },
        ],
        budgetamount: [
            { required: false, type: 'number', message: '预算金额 值不能为空', trigger: 'change' },
            { required: false, type: 'number', message: '预算金额 值不能为空', trigger: 'blur' },
        ],
        purchaseprocess: [
            { required: false, type: 'string', message: '采购程序 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: '采购程序 值不能为空', trigger: 'blur' },
        ],
        description: [
            { required: false, type: 'string', message: '说明 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: '说明 值不能为空', trigger: 'blur' },
        ],
        currentsituation: [
            { required: false, type: 'string', message: '当前状况 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: '当前状况 值不能为空', trigger: 'blur' },
        ],
        customerneed: [
            { required: false, type: 'string', message: '客户需求 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: '客户需求 值不能为空', trigger: 'blur' },
        ],
        proposedsolution: [
            { required: false, type: 'string', message: '已拟定解决方案 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: '已拟定解决方案 值不能为空', trigger: 'blur' },
        ],
        pricelevelname: [
            { required: false, type: 'string', message: '价目表 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: '价目表 值不能为空', trigger: 'blur' },
        ],
        parentcontactid: [
            { required: false, type: 'string', message: '联系人 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: '联系人 值不能为空', trigger: 'blur' },
        ],
        parentaccountid: [
            { required: false, type: 'string', message: '帐户 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: '帐户 值不能为空', trigger: 'blur' },
        ],
        transactioncurrencyid: [
            { required: false, type: 'string', message: '货币 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: '货币 值不能为空', trigger: 'blur' },
        ],
        opportunityid: [
            { required: false, type: 'string', message: '商机 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: '商机 值不能为空', trigger: 'blur' },
        ],
        pricelevelid: [
            { required: false, type: 'string', message: '价目表 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: '价目表 值不能为空', trigger: 'blur' },
        ],
    }

    /**
     * 详情模型集合
     *
     * @type {*}
     * @memberof MainEditFormBase
     */
    public detailsModel: any = {
        group1: new FormGroupPanelModel({ caption: '基本信息', detailType: 'GROUPPANEL', name: 'group1', visible: true, isShowCaption: true, form: this, uiActionGroup: { caption: '', langbase: 'entities.opportunity.main_form', extractMode: 'ITEM', details: [] } }),

        druipart1: new FormDRUIPartModel({ caption: '', detailType: 'DRUIPART', name: 'druipart1', visible: true, isShowCaption: true, form: this }),

        grouppanel1: new FormGroupPanelModel({ caption: '产品明细信息', detailType: 'GROUPPANEL', name: 'grouppanel1', visible: true, isShowCaption: true, form: this, uiActionGroup: { caption: '', langbase: 'entities.opportunity.main_form', extractMode: 'ITEM', details: [] } }),

        formpage1: new FormPageModel({ caption: '基本信息', detailType: 'FORMPAGE', name: 'formpage1', visible: true, isShowCaption: true, form: this }),

        srfupdatedate: new FormItemModel({ caption: '更新时间', detailType: 'FORMITEM', name: 'srfupdatedate', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 0 }),

        srforikey: new FormItemModel({ caption: '', detailType: 'FORMITEM', name: 'srforikey', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        srfkey: new FormItemModel({ caption: '商机', detailType: 'FORMITEM', name: 'srfkey', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 1 }),

        srfmajortext: new FormItemModel({ caption: '商机名称', detailType: 'FORMITEM', name: 'srfmajortext', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        srftempmode: new FormItemModel({ caption: '', detailType: 'FORMITEM', name: 'srftempmode', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        srfuf: new FormItemModel({ caption: '', detailType: 'FORMITEM', name: 'srfuf', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        srfdeid: new FormItemModel({ caption: '', detailType: 'FORMITEM', name: 'srfdeid', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        srfsourcekey: new FormItemModel({ caption: '', detailType: 'FORMITEM', name: 'srfsourcekey', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        opportunityname: new FormItemModel({ caption: '商机名称', detailType: 'FORMITEM', name: 'opportunityname', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        parentcontactname: new FormItemModel({ caption: '联系人', detailType: 'FORMITEM', name: 'parentcontactname', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        parentaccountname: new FormItemModel({ caption: '帐户', detailType: 'FORMITEM', name: 'parentaccountname', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        purchasetimeframe: new FormItemModel({ caption: '购买时间范围', detailType: 'FORMITEM', name: 'purchasetimeframe', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        transactioncurrencyname: new FormItemModel({ caption: '货币', detailType: 'FORMITEM', name: 'transactioncurrencyname', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        budgetamount: new FormItemModel({ caption: '预算金额', detailType: 'FORMITEM', name: 'budgetamount', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        purchaseprocess: new FormItemModel({ caption: '采购程序', detailType: 'FORMITEM', name: 'purchaseprocess', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        description: new FormItemModel({ caption: '说明', detailType: 'FORMITEM', name: 'description', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        currentsituation: new FormItemModel({ caption: '当前状况', detailType: 'FORMITEM', name: 'currentsituation', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        customerneed: new FormItemModel({ caption: '客户需求', detailType: 'FORMITEM', name: 'customerneed', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        proposedsolution: new FormItemModel({ caption: '已拟定解决方案', detailType: 'FORMITEM', name: 'proposedsolution', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        pricelevelname: new FormItemModel({ caption: '价目表', detailType: 'FORMITEM', name: 'pricelevelname', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        parentcontactid: new FormItemModel({ caption: '联系人', detailType: 'FORMITEM', name: 'parentcontactid', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        parentaccountid: new FormItemModel({ caption: '帐户', detailType: 'FORMITEM', name: 'parentaccountid', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        transactioncurrencyid: new FormItemModel({ caption: '货币', detailType: 'FORMITEM', name: 'transactioncurrencyid', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        opportunityid: new FormItemModel({ caption: '商机', detailType: 'FORMITEM', name: 'opportunityid', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 1 }),

        pricelevelid: new FormItemModel({ caption: '价目表', detailType: 'FORMITEM', name: 'pricelevelid', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

    };
}